@@ -4,7 +4,7 @@
  *
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
  * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi
- * Copyright (C) 2002-2005 Paolo Maggi
+ * Copyright (C) 2002-2006 Paolo Maggi
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,11 +23,11 @@
  */
 
 /*
- * Modified by the gedit Team, 1998-2005. See the AUTHORS file for a
+ * Modified by the gedit Team, 1998-2006. See the AUTHORS file for a
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-search.c,v 1.8 2006/03/13 17:58:41 pborelli Exp $
+ * $Id: gedit-commands-search.c,v 1.11 2006/05/29 10:14:28 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,7 +50,6 @@
 #define GEDIT_SEARCH_DIALOG_KEY		"gedit-search-dialog-key"
 #define GEDIT_LAST_SEARCH_DATA_KEY	"gedit-last-search-data-key"
 
-
 /* data stored in the document
  * to persist the last searched
  * words and options
@@ -307,7 +306,7 @@ do_find (GeditSearchDialog *dialog,
 	}
 
 	g_free (search_text);
-
+	
 	found = run_search (active_view,
 			    wrap_around,
 			    search_backwards);
@@ -514,7 +513,7 @@ search_dialog_destroyed (GeditWindow       *window,
 }
 
 void
-gedit_cmd_search_find (GtkAction   *action,
+_gedit_cmd_search_find (GtkAction   *action,
 		       GeditWindow *window)
 {
 	gpointer data;
@@ -595,7 +594,7 @@ gedit_cmd_search_find (GtkAction   *action,
 }
 
 void
-gedit_cmd_search_replace (GtkAction   *action,
+_gedit_cmd_search_replace (GtkAction   *action,
 			  GeditWindow *window)
 {
 	gpointer data;
@@ -682,17 +681,28 @@ do_find_again (GeditWindow *window,
 	       gboolean     backward)
 {
 	GeditView *active_view;
-
+	GtkTextBuffer *buffer;
+	gboolean wrap_around = TRUE;
+	LastSearchData *data;
+	
 	active_view = gedit_window_get_active_view (window);
 	g_return_if_fail (active_view != NULL);
 
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (active_view));
+
+	data = g_object_get_data (G_OBJECT (buffer), 
+				  GEDIT_LAST_SEARCH_DATA_KEY);
+
+	if (data != NULL)
+		wrap_around = data->wrap_around;					    
+
 	run_search (active_view,
-	   	    TRUE,
+	   	    wrap_around,
 	   	    backward);
 }				 
 
 void
-gedit_cmd_search_find_next (GtkAction   *action,
+_gedit_cmd_search_find_next (GtkAction   *action,
 			    GeditWindow *window)
 {
 	gedit_debug (DEBUG_COMMANDS);
@@ -701,7 +711,7 @@ gedit_cmd_search_find_next (GtkAction   *action,
 }
 
 void
-gedit_cmd_search_find_prev (GtkAction   *action,
+_gedit_cmd_search_find_prev (GtkAction   *action,
 			    GeditWindow *window)
 {
 	gedit_debug (DEBUG_COMMANDS);
@@ -710,7 +720,7 @@ gedit_cmd_search_find_prev (GtkAction   *action,
 }
 
 void
-gedit_cmd_search_clear_highlight (GtkAction   *action,
+_gedit_cmd_search_clear_highlight (GtkAction   *action,
 				  GeditWindow *window)
 {
 	GeditDocument *doc;
@@ -724,7 +734,7 @@ gedit_cmd_search_clear_highlight (GtkAction   *action,
 }
 
 void
-gedit_cmd_search_goto_line (GtkAction   *action,
+_gedit_cmd_search_goto_line (GtkAction   *action,
 			    GeditWindow *window)
 {
 	GeditView *active_view;
