@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.c,v 1.76 2006/04/20 17:01:13 paolo Exp $
+ * $Id: gedit-utils.c,v 1.77 2006/05/02 10:07:47 sfre Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -134,6 +134,56 @@ gedit_utils_menu_position_under_widget (GtkMenu  *menu,
 	*push_in = TRUE;
 }
 
+void
+gedit_utils_menu_position_under_tree_view (GtkMenu  *menu,
+					   gint     *x,
+					   gint     *y,
+					   gboolean *push_in,
+					   gpointer  user_data)
+{
+	GtkTreeView *tree = GTK_TREE_VIEW (user_data);
+	GtkTreeModel *model;
+	GtkTreeSelection *selection;
+	GtkTreeIter iter;
+	
+	model = gtk_tree_view_get_model (tree);
+	g_return_if_fail (model != NULL);
+
+	selection = gtk_tree_view_get_selection (tree);
+	g_return_if_fail (selection != NULL);
+
+	if (gtk_tree_selection_get_selected (selection, NULL, &iter))
+	{
+		GtkTreePath *path;
+		GdkRectangle rect;
+
+		gdk_window_get_origin (GTK_WIDGET (tree)->window, x, y);
+			
+		path = gtk_tree_model_get_path (model, &iter);
+		gtk_tree_view_get_cell_area (tree, path,
+					     gtk_tree_view_get_column (tree, 0), /* FIXME 0 for RTL ? */
+					     &rect);
+		gtk_tree_path_free (path);
+		
+		*x += rect.x;
+		*y += rect.y + rect.height;
+		
+		if (gtk_widget_get_direction (GTK_WIDGET (tree)) == GTK_TEXT_DIR_RTL)
+		{
+			GtkRequisition requisition;
+			gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
+			*x += rect.width - requisition.width;
+		}
+	}
+	else
+	{
+		/* no selection -> regular "under widget" positioning */
+		gedit_utils_menu_position_under_widget (menu,
+							x, y, push_in,
+							tree);
+	}
+}
+
 GtkWidget *
 gedit_gtk_button_new_with_stock_icon (const gchar *label,
 				      const gchar *stock_id)
