@@ -78,6 +78,8 @@ static GeditLanguage known_languages [] =
 {
 	{"af", N_("Afrikaans")},
 	{"am", N_("Amharic")},
+	{"ar", N_("Arabic")},
+	{"ar_EG", N_("Arabic (Egypt)")},
 	{"az", N_("Azerbaijani")},
 	{"be", N_("Belarusian")},
 	{"bg", N_("Bulgarian")},
@@ -123,6 +125,7 @@ static GeditLanguage known_languages [] =
 	{"mi", N_("Maori")},
 	{"mk", N_("Macedonian")},
 	{"mn", N_("Mongolian")},
+	{"mr", N_("Marathi")},
 	{"ms", N_("Malay")},
 	{"mt", N_("Maltese")},
 	{"nb", N_("Norwegian Bokmal")},
